@@ -5,22 +5,16 @@ test_that("syllable_count, gives the desired output",{
     x1 <- syllable_count("Robots like Dason lie.")
     x2 <- syllable_count("Robots like Dason lie.", algorithm.report = TRUE)
 
-    x1_c <- structure(list(words = structure(c(4L, 3L, 1L, 2L), .Label = c("dason", 
-        "lie", "like", "robots"), class = "factor"), syllables = c(2, 
-        1, 2, 1), in.dictionary = structure(c(1L, 1L, 2L, 1L), .Label = c("-", 
-        "NF"), class = "factor")), .Names = c("words", "syllables", "in.dictionary"
-        ), row.names = c(NA, -4L), class = "data.frame")
-
-    x2_c <- structure(list(`ALGORITHM REPORT` = structure(list(words = structure(1L, .Label = c("dason", 
-        "lie", "like", "robots"), class = "factor"), syllables = 2, in.dictionary = structure(2L, .Label = c("-", 
-        "NF"), class = "factor")), .Names = c("words", "syllables", "in.dictionary"
-        ), row.names = 3L, class = "data.frame"), `SYLLABLE DATAFRAME` = structure(list(
-            words = structure(c(4L, 3L, 1L, 2L), .Label = c("dason", 
-            "lie", "like", "robots"), class = "factor"), syllables = c(2, 
-            1, 2, 1), in.dictionary = structure(c(1L, 1L, 2L, 1L), .Label = c("-", 
-            "NF"), class = "factor")), .Names = c("words", "syllables", 
-        "in.dictionary"), row.names = c(NA, -4L), class = "data.frame")), 
-        .Names = c("ALGORITHM REPORT", "SYLLABLE DATAFRAME"))
+    x1_c <- structure(list(words = c("robots", "like", "dason", "lie"), syllables = c(2, 
+        1, 2, 1), in.dictionary = c("-", "-", "NF", "-")), class = "data.frame", row.names = c(NA, 
+        -4L))
+    
+    x2_c <- list(`ALGORITHM REPORT` = structure(list(words = "dason", syllables = 2, 
+        in.dictionary = "NF"), row.names = 3L, class = "data.frame"), 
+        `SYLLABLE DATAFRAME` = structure(list(words = c("robots", 
+        "like", "dason", "lie"), syllables = c(2, 1, 2, 1), in.dictionary = c("-", 
+        "-", "NF", "-")), class = "data.frame", row.names = c(NA, 
+        -4L)))
    
     expect_equivalent(x1, x1_c)
     expect_equivalent(x2, x2_c)
@@ -79,4 +73,4 @@ test_that("cumulative methods for syllable_freq, gives the desired output",{
     expect_true(all(colnames(x3_cum) == c("cumave", "Time")))
     expect_true(is.data.frame(x4_cum))
     expect_true(all(colnames(x4_cum) == c("cumave", "Time")))
-})
\ No newline at end of file
+})
